@@ -1,9 +1,10 @@
 from tinderboxhandler import TinderboxHandler
 from pvtbuildshandler import PvtbuildsHandler
 from releasemohandler import ReleaseMOHandler
+from nightlyftpmohandler import NightlyFtpMOHandler
 
 __all__ = ['all_handlers']
-all_handlers = ['TinderboxHandler', 'PvtbuildsHandler', 'ReleaseMOHandler']
+all_handlers = ['TinderboxHandler', 'PvtbuildsHandler', 'ReleaseMOHandler', 'NightlyFtpMOHandler']
 __all__.extend(all_handlers)
 
 
